format_context_files

Function format_context_files 

pub fn format_context_files(files: &[FileContext]) -> Option<String>
Format file contexts into a string suitable for injection into the user message sent to the LLM.