pub fn format_context_files(files: &[FileContext]) -> Option<String>Expand description
Format file contexts into a string suitable for injection into the user message sent to the LLM.
pub fn format_context_files(files: &[FileContext]) -> Option<String>Format file contexts into a string suitable for injection into the user message sent to the LLM.