Streaming markdown → ratatui Line renderer.
Converts raw markdown text (line by line) into styled ratatui
Lines with headers, bold, italic, inline code, fenced code
blocks (with syntax highlighting), lists, blockquotes, and HRs.
This replaces the old ANSI-based markdown.rs with native ratatui types.
Structs
- Markdown
Renderer - Streaming markdown renderer that tracks fenced code block state.